@@ -19,16 +19,97 @@ import base64
 import pandas as pd
 import chempy as cp
 import requests
+from sympy import *
+import urllib.parse
+import random
+from collections import OrderedDict
+import chempy as cp
 
-def superLoc(df,idx,*cols):
+def superLoc(df,idx,*cols,converters={},sample=None):
+    if sample != None:
+        idx = random.sample(list(df.index),sample)
     if isinstance(idx,int):
-        return tuple([df.loc[idx,col] for col in cols])
+        return tuple([converters.get(col,lambda x:x)(df.loc[idx,col]) for col in cols])
     elif isinstance(idx,list):
-        return tuple([[df.loc[indx,col] for indx in idx] for col in cols])
+        return tuple([[converters.get(col,lambda x:x)(df.loc[indx,col]) for indx in idx] for col in cols])
 
 def convert2img(url,sizeX=200,sizeY=200):
     return f"""<p><img src="{url}" alt="" width="{sizeX}" /></p>"""
 
+def convertRedox2Reac(Ox1,Red1,Ox2,Red2):
+    """Ox,Red orderedDict of 1/2 Eq reaction
+    return reac,prod : set of reaction
+    """
+    e1 = cp.Equilibrium(ox1, red1)
+    e2 = cp.Equilibrium(red2 , ox2)
+    cs = cp.Equilibrium.eliminate([e1, e2], 'e-')
+    redox_eq = str(e1*cs[0] + e2*cs[1]).replace("=","->")
+    redox_eq = cp.Reaction.from_string(redox_eq)
+    prod = set(redox_eq.prod)
+    reac = set(redox_eq.reac)
+    return reac,prod
+
+def convert2LatexXAZ(el,A,Z):
+    """ convertit el,A,Z en représentation latex
+        el : str Ex H
+        A,Z chimie
+    """
+    txt = f"""{{\\displaystyle {{}}_{{{Z}}}^{{{A}}}\operatorname {{{el}}} }}"""
+    return txt
+
+def convertList2Str(L,sep=', '):
+    txt = ", ".join(L[:-1])
+    txt += " et "+L[-1]       
+    return txt
+
+def convert2gfx(gfx_text,x_min=-10,x_max=10,y_min=-10,y_max=10,dx=1,dy=1):
+    gfx_text = str(urllib.parse.quote(gfx_text))
+    url = f"""https://graphsketch.com/?eqn1_color=1&eqn1_eqn={gfx_text}&eqn2_color=2&eqn2_eqn=&eqn3_color=3&eqn3_eqn=&eqn4_color=4&eqn4_eqn=&eqn5_color=5&eqn5_eqn=&eqn6_color=6&eqn6_eqn=&x_min={x_min}&x_max={x_max}&y_min={y_min}&y_max={y_max}&x_tick={dx}&y_tick={dy}&x_label_freq=5&y_label_freq=5&do_grid=0&do_grid=1&bold_labeled_lines=0&bold_labeled_lines=1&line_width=4&image_w=650&image_h=425"""
+    iframe = f"""<p><iframe style="width: 850px; height: 495px; overflow: hidden;" src="{url}" width="1000" height="1000" scrolling="no">Iframes not supported</iframe></p>"""
+    return iframe
+
+def convert2gfx3(gfx_text1,gfx_text2,gfx_text3,x_min=-10,x_max=10,y_min=-10,y_max=10,dx=1,dy=1,colors = [1,2,3]):
+    gfx_text1 = str(urllib.parse.quote(gfx_text1))
+    gfx_text2 = str(urllib.parse.quote(gfx_text2))
+    gfx_text3 = str(urllib.parse.quote(gfx_text3))
+    c1,c2,c3 = tuple(colors)
+    url = f"""https://graphsketch.com/?eqn1_color={c1}&eqn1_eqn={gfx_text1}&eqn2_color={c2}&eqn2_eqn={gfx_text2}&eqn3_color={c3}&eqn3_eqn={gfx_text3}&eqn4_color=4&eqn4_eqn=&eqn5_color=5&eqn5_eqn=&eqn6_color=6&eqn6_eqn=&x_min={x_min}&x_max={x_max}&y_min={y_min}&y_max={y_max}&x_tick={dx}&y_tick={dy}&x_label_freq=5&y_label_freq=5&do_grid=0&do_grid=1&bold_labeled_lines=0&bold_labeled_lines=1&line_width=4&image_w=650&image_h=425"""
+    iframe = f"""<p><iframe style="width: 850px; height: 495px; overflow: hidden;" src="{url}" width="1000" height="1000" scrolling="no">Iframes not supported</iframe></p>"""
+    return iframe
+
+def convert2link(url,title = "link"):
+    return f"""<a title="{title}" href="{url}" target="_blank" rel="noopener">url</a></p>"""
+
+
+import requests
+import json
+
+def convert2wiki_main_image(title):
+    url = 'https://en.wikipedia.org/w/api.php'
+    data = {
+        'action' :'query',
+        'format' : 'json',
+        'formatversion' : 2,
+        'prop' : 'pageimages|pageterms',
+        'piprop' : 'original',
+        'titles' : title
+    }
+    response = requests.get(url, data)
+    json_data = json.loads(response.text)
+    result = json_data['query']['pages'][0]['original']['source'] if len(json_data['query']['pages']) >0 else 'Not found'
+    if result != "Not found":
+        return convert2img(result)
+    else:
+        return None
+    
+def convert2HTMLList(tab):
+    txt = "<ul>"
+    for t in tab:
+        txt += f"<li>{t}</li>"
+    txt += "</ul>"
+    return txt
+        
+
 def convert2sci(x,CS=3):
     CS = int(sorted([2,CS,10])[1])
     mantisse,puiss = f"""{x:.10e}""".split("e")
@@ -37,8 +118,57 @@ def convert2sci(x,CS=3):
     if int(puiss)==0:
         return f"""{mantisse}"""
     else:
-        return f"""{mantisse}{multiply}10<sup>{int(puiss)}</sup>"""   
-    
+        return f"""{mantisse} {multiply} 10<sup>{int(puiss)}</sup>"""   
+
+def convert2sci_unicode(x,CS=3):
+    unic_exp = {'-':"⁻",'0':0x2070, '1':0x00B9, '2':0x00B2, '3':0x00B3, '4':0x2074, '5':0x2075, '6':0x2076, '7':0x2077, '8':0x2078, '9':0x2079}
+    CS = int(sorted([2,CS,10])[1])
+    if x == 0:
+        return "0"
+    mantisse,puiss = f"""{x:.10e}""".split("e")
+    puiss = int(puiss)
+    mantisse=mantisse[:mantisse.index('.')+CS+1]
+    multiply = 	u"\u00D7"
+    txt_puiss = str(puiss)
+    print(txt_puiss)
+    txt_expression = ""
+    for t in txt_puiss:
+        if t == "-":
+            txt_expression += unic_exp[t]
+        else: txt_expression += chr(unic_exp[t])
+    if puiss==0:
+        return f"""{mantisse}"""
+    else:
+        return f"""{mantisse} {multiply} 10{txt_expression}"""   
+
+def shuffleList(*L):
+    """
+    Parameters
+    ----------
+    *L : tuple de listes
+
+    Returns
+    -------
+    tuple de listes mélangé
+
+    """
+    list_zipped = list(zip(*L))
+    random.shuffle(list_zipped)
+    return zip(*list_zipped) #unzipping
+
+def convert2chemTopo(cid):
+    """
+    Parameters
+    ----------
+    cid : (int)
+
+    Returns
+    -------
+    (str) url de l'image topologique de la molécule cid.
+
+    """
+    return f"""<p><img src="https://pubchem.ncbi.nlm.nih.gov/image/imgsrv.fcgi?cid={cid}&amp;t=l" alt="" width="250" height="250" /></p>"""
+
 def convertDegreDec2DegMin(dd,opt=None,typ="GPS"):
     """
     params : 
@@ -88,6 +218,7 @@ def convert2chemFormula(formula):
 
 def convert2chem3D(cid,width=300,height=200):
     return f"""<iframe style="width: {width}px; height: {height}px;" frameborder="0" src="https://embed.molview.org/v1/?mode=balls&cid={cid}&bg=white"></iframe>"""
+
 def alea(mmin,mmax,precision):
     p = 10**-precision
     return round(random.uniform(mmin/p,mmax/p))*p
@@ -167,7 +298,20 @@ def num_q(x,p=0.001,sci = False,score=1):
 def str_q(x,score=1):
     return "{"+f"{score}:SHORTANSWER:="+"%s}" %(x)
 
-num_qr = lambda x,y,score=1:num_q(x,x*y,score=score)
+def num_qr(x,precision=0.02,score=1):
+    if x == 0:
+        return num_q(0,1e-4,score=score)
+    else:
+        return num_q(x,x*precision,score=score)
+
+def num_qr_list(xs,qs=[],unit="",precision=0.02,score=1):
+    if isinstance(unit,str):
+        unit = [unit]*len(xs)
+    if qs == []:
+        qs = ["  "]*len(xs)
+    tab = [q+"  :"+num_qr(x,precision=precision,score=score)+f" {u}" for x,q,u in zip(xs,qs,unit)]
+    return convert2HTMLList(tab)
+    
 
 def multi_qr(list_good_reply,list_reply,score = 1,typ="MC"):
     if isinstance(list_good_reply,str):
@@ -292,6 +436,7 @@ def moodle_xml(name, questions, template_fun, category = '',iostream=sys.stdout)
     
 class Jokers:
     def __init__(self,var,nb,stype,converters={}):
+        stype = stype.replace(" ","").replace("_","")
         assert len(stype)==len(var)*nb,f"incorrect lenght stype lenght -> {len(stype)} | vars -> {len(var)*nb}"
         assert ("0" in stype or "1" in stype),f"stype {stype} ne doit contenir que 0 ou 1"
         self.var = var
@@ -368,7 +513,10 @@ class Jokers:
                 if lst[idx] != fill_default:
                     r = fnct(lst[idx])
                     if output_format == None:
-                        result += f"{v}={r}\n"
+                        if isinstance(r,str):
+                            result += f"""{v}="{r}"\n"""
+                        else:
+                            result += f"""{v}={r}\n"""
                     else:
                         toto = format(r,output_format)
                         result += f"{v}= '{toto}'\n"
