@@ -145,15 +145,18 @@ def exfw(tmp_url='',url_type="gd",glob_var=None):
 
 def set_spy(func):
     def search_traceback(t,k,fname,name):
-        t0 = t.replace(' ','')
-        t0=t0.lstrip(t0[:t0.index(k)]).rstrip(")")
-        x= t0[t0.index(k)+len(k)+1]
-        if x=='[':
-            result = t0[t0.index(k)+len(k)+2:t0.index(']')].split(',')
-            result.sort()
-        else:
-            result = t0.split(",")[0].split("=")[1]
-        return result
+        try:
+            t0 = t.replace(' ','')
+            t0=t0.lstrip(t0[:t0.index(k)]).rstrip(")")
+            x= t0[t0.index(k)+len(k)+1]
+            if x=='[':
+                result = t0[t0.index(k)+len(k)+2:t0.index(']')].split(',')
+                result.sort()
+            else:
+                result = t0.split(",")[0].split("=")[1]
+            return result
+        except:
+            return None
 
     def modif(*args, **kwargs):
         fname = func.__name__
@@ -175,6 +178,8 @@ def set_spy(func):
             keys = {'x':0,'y':0,'degre':1}
         elif fname == 'draw_vectors':
             keys = {'point':0,'vector':0}
+        elif fname == 'scatter1D':
+            keys = {'x':0 }
         (_,_,_,text)=traceback.extract_stack()[-2]
         def_name = text[:text.find('.'+fname)].strip()
         if (def_name == 'self') and (fname=='scatter2D'):
@@ -224,7 +229,6 @@ def scatterPolar(self,other_df=None, theta='theta', r='R', titre="",
             datf.append(elem)
     courbes = []
     i = 0
-    symbol, s = ["circle",17,3,4,29,29,23,24,10,11,15], list(r'o*+x[]<>/\%')
     for data in datf:
         if not check_info(data):
             print(f"Avertissement - dataframe sans nom\nEcrire ma_dataframe.info='quelque chose'")
@@ -240,15 +244,13 @@ def scatterPolar(self,other_df=None, theta='theta', r='R', titre="",
                 r[i] = txt
             xyz=go.Scatterpolar(theta=data[theta][::unsur],r=data[ordonnee][::unsur],
                                name=f"{ordonnee}/({nom})")
-            if style_tracer in s:
-                xyz['mode']="markers"
-                xyz['marker']['symbol'] = symbol[s.index(style_tracer)]
-            elif style_tracer in ['-o','o-']:
-                xyz['mode']="lines+markers"
-                xyz['line']['shape']='spline'
-            else:
-                xyz['mode']="lines"
+            mode_symbol_dask = marker_to_plotly_marker(style_tracer)
+            xyz['mode'] = mode_symbol_dask['mode']
+            if 'markers' in xyz['mode']:
+                xyz['marker']['symbol'] = mode_symbol_dask['symbol']
+            if 'lines' in xyz['mode']:
                 xyz['line']['shape']='spline'
+                xyz['line']['dash'] = mode_symbol_dask['dash']
             if color=='auto':
                 xyz['marker']['color']=couleur[i]
             elif color=='rainbow':
@@ -272,7 +274,7 @@ def scatterPolar(self,other_df=None, theta='theta', r='R', titre="",
     return iplot(fig,filename=titre)
 
 @ set_spy
-def histogram(self,x='x',titre='pas de titre',orientation='vertical',histnorm=""):
+def histogram(self,x=None,titre='pas de titre',orientation='vertical',histnorm=""):
    """
    Trace un histogramme de la grandeur 'x'
    Arguments:
@@ -288,6 +290,8 @@ def histogram(self,x='x',titre='pas de titre',orientation='vertical',histnorm=""
         les histogrammes de 'x' et 'y'
         >df.histogram(x=['x','y'])
    """
+   if x == None:
+       x = list(self.columns)
    x = format_to_valid_y(x)
    courbes=[]
    for elem in x:
@@ -322,8 +326,8 @@ def wavelength_to_rgb(wavelength, gamma=0.8):
     '''
 
     wavelength = float(wavelength)
-    if wavelength >= 380 and wavelength <= 440:
-        attenuation = 0.3 + 0.7 * (wavelength - 380) / (440 - 380)
+    if wavelength >= 400 and wavelength <= 440:
+        attenuation = 0.3 + 0.7 * (wavelength - 400) / (440 - 400)
         R = ((-(wavelength - 440) / (440 - 380)) * attenuation) ** gamma
         G = 0.0
         B = (1.0 * attenuation) ** gamma
@@ -343,8 +347,8 @@ def wavelength_to_rgb(wavelength, gamma=0.8):
         R = 1.0
         G = (-(wavelength - 645) / (645 - 580)) ** gamma
         B = 0.0
-    elif wavelength >= 645 and wavelength <= 750:
-        attenuation = 0.3 + 0.7 * (750 - wavelength) / (750 - 645)
+    elif wavelength >= 645 and wavelength <= 800:
+        attenuation = 0.3 + 0.7 * (800 - wavelength) / (800 - 645)
         R = (1.0 * attenuation) ** gamma
         G = 0.0
         B = 0.0
@@ -355,25 +359,60 @@ def wavelength_to_rgb(wavelength, gamma=0.8):
     R *= 255
     G *= 255
     B *= 255
-    return (int(R), int(G), int(B))
+    return f"rgb({int(R)},{int(G)},{int(B)})"
 
 
 @ set_spy
-def scatter1D(self,x='lamb',titre='',xlabel='',other_df=None,style_tracer='|'):
-    self['__color'] = wavelength_to_rgb(self[x])
-    self['__y']=0
-    
-    xyz=go.Scatter(x=self[x],y=self['__y'],marker=dict(size=4),
-                               name=f"{ordonnee}/({nom})"[:50])
-    quiver_fig = ff.create_quiver(self[x],0, 0, 1,
-                       angle=0,
-                       line=dict(width=1))
-    xx_label = xlabel if x_label=='' else x
-    layout= go.Layout(title= titre,xaxis= dict(title=xx_label ),yaxis=dict(title= ''))
-    quiver_fig.add_trace(xyz)
-    quiver_fig['layout'].update(layout)
-    return iplot(quiver_fig, filename='LO')
+def scatter1D(self,x='lamb',titre='',xlabel='',other_df=None,style_tracer='|',**d):
+    gamma = d.get('gamma',0.4)
+    self['__color'] = [wavelength_to_rgb(xi,gamma=gamma) for xi in self[x]]
+    self['__y'] = 0
+    self['__uy'] = 1
+    line_shapes = [{'type':'line','x0':xx,'y0':0,'x1':xx,'y1':1,'line':{'color':cc,'width':3}} for xx,cc in zip(self[x],self['__color'])]
+    xyz=go.Scatter(x=self[x],y=self['__y'],marker={'size':7,'color':self['__color']},mode='markers')
+    xx_label = xlabel if xlabel=='' else x
+    layout= go.Layout(title= titre,xaxis= dict(title=xx_label),yaxis=dict(title= ''),shapes=line_shapes)
+    fig = go.Figure(data=xyz, layout=layout)
+    self.drop(columns=['__color','__y','__uy'],inplace=True)
+    return iplot(fig, filename='LO')
 
+def marker_to_plotly_marker(markers):
+    if markers in [None,'']:
+        return
+    symbol, s = ["circle","circle-open","square","square-open","diamond","diamond-open","cross","x"], list(r'oO[<>+x')
+    marker_typ = {k:v for k,v in zip(s,symbol)}
+    #mode = lines;markers;lines+markers
+    #dash => "solid", "dot", "dash", "longdash", "dashdot", or "longdashdot"
+    #symbol => yen a plein
+    #symbol 3D "circle" | "circle-open" | "square" | "square-open" | "diamond" | "diamond-open" | "cross" | "x"  
+    line_typ = {':':'dot','.':'dash',';':'longdash','-':'solid'}
+    result = {'mode':'markers','symbol':'xxx','dash':'xxx'} #default result
+    #check if lines.
+    mar,lin = '',''
+    #check if lines.
+    for k,v in line_typ.items():
+        if k in markers:
+            lin = 'lines'
+            result['dash'] = v
+            break
+   #check if markers:
+    for k,v in marker_typ.items():
+       if k in markers:
+           mar = 'markers'
+           result['symbol']=v
+           break
+    if (lin == 'lines') and (mar == 'markers'):
+        result['mode'] = 'lines+markers'
+    elif (lin == '') and ( mar == 'markers'):
+        result['dash']=''
+        result['mode'] = 'markers'
+    elif (lin == 'lines') and (mar == ''):
+        result['symbol'] = ''
+        result['mode'] = 'lines'
+    assert result['symbol'] != 'xxx',f"marker symbol must be in {marker_typ.keys()} or None"
+    assert result['dash'] != 'xxx',f"marker dash must be in {line_typ.keys()} or None"
+    return result
+               
 @ set_spy           
 def scatter2D(self, other_df=None, x='t', y='X', titre="",
               ortho='auto', unsur=1, style_tracer='o',
@@ -436,7 +475,7 @@ def scatter2D(self, other_df=None, x='t', y='X', titre="",
         origin = True
     courbes = []
     i = 0
-    symbol, s = ["circle",17,3,4,29,29,23,24,10,11,15], list(r'o*+x[]<>/\%')
+    #symbol, s = ["circle",17,3,4,29,29,23,24,10,11,15], list(r'o*+x[]<>/\%')
     for data in datf:
         if not check_info(data):
             print(f"Avertissement - dataframe sans nom\nEcrire ma_dataframe.info='quelque chose'")
@@ -457,21 +496,13 @@ def scatter2D(self, other_df=None, x='t', y='X', titre="",
                 xyz=go.Scatter(x=data[x][::unsur]-origin_df[x][::unsur],y=data[ordonnee][::unsur]-origin_df[ordonnee][::unsur],
                                    marker=dict(size=4),name=f"{ordonnee}({nom})"[:50])
                 xyz_origin = go.Scatter(x=np.zeros(1),y=np.zeros(1),marker=dict(size=4),name=f"{origin_df.info}"[:50])
-            if style_tracer in s:
-                xyz['mode']="markers"
-                xyz['marker']['symbol'] = symbol[s.index(style_tracer)]
-            elif style_tracer in ['-o','o-']:
-                xyz['mode']="lines+markers"
+            mode_symbol_dask = marker_to_plotly_marker(style_tracer)
+            xyz['mode'] = mode_symbol_dask['mode']
+            if 'markers' in xyz['mode']:
+                xyz['marker']['symbol'] = mode_symbol_dask['symbol']
+            if 'lines' in xyz['mode']:
                 xyz['line']['shape']='spline'
-            elif style_tracer == ':':
-                xyz['mode']="lines"
-                xyz['line']['dash'] = 'dot'
-            elif style_tracer == ';':
-                xyz['mode']="lines"
-                xyz['line']['dash'] = 'dash'
-            else:
-                xyz['mode']="lines"
-                xyz['line']['shape'] = 'spline'
+                xyz['line']['dash'] = mode_symbol_dask['dash']
             if color=='auto':
                 xyz['marker']['color']=couleur[i]
             elif color=='rainbow':
@@ -499,7 +530,7 @@ def scatter2D(self, other_df=None, x='t', y='X', titre="",
     y_label = " | ".join(y) if ylabel == '' else ylabel
     quadril_x = int(max(min(quadril_x,50),0))
     quadril_x = int(max(min(quadril_x,50),0))
-    autorange = True if xorder == 'normal' else 'reversed'
+    autorange = True if xorder == 'normal' else "reversed"
     layout= go.Layout(title= titre,xaxis= dict(autorange=autorange,title = x_label,nticks=quadril_x),yaxis=dict(nticks=quadril_y,title=y_label ))
     if ortho=='ortho':
         layout['xaxis']['constrain'] ='domain'
@@ -522,7 +553,7 @@ def scatter2D(self, other_df=None, x='t', y='X', titre="",
     return iplot(fig,filename=titre)
 
 @ set_spy
-def scatter3D(self, other_df=None, x='X', y='Y', z='Z', titre="un titre", unsur=1,color='auto',origin_df=None,style_tracer='o'):
+def scatter3D(self, other_df=None, x='X', y='Y', z='Z', titre="un titre", unsur=1,color='auto',origin_df=None,style_tracer='o',xlabel='',ylabel='',zlabel=''):
     """
         Méthode/Fonction appliquée à une dataframe -> retourne un graphique plotly en 3D
         Arguments, signification et valeurs par defauts
@@ -563,35 +594,35 @@ def scatter3D(self, other_df=None, x='X', y='Y', z='Z', titre="un titre", unsur=
         if not check_info(df):
             df.info = "pas d'info"
         if not origin:
-            xyz=go.Scatter3d(x=df[x][::unsur], y=df[y][::unsur], z=df[z][::unsur], mode='markers', marker=dict(colorscale='Rainbow',
-                                                    size=3), name=df.info)
+            xyz=go.Scatter3d(x=df[x][::unsur], y=df[y][::unsur], z=df[z][::unsur],name=df.info)
         else:
             xyz=go.Scatter3d(x=df[x][::unsur]-origin_df[x][::unsur], y=df[y][::unsur]-origin_df[y][::unsur],
-                             z=df[z][::unsur]-origin_df[z][::unsur], mode='markers', marker=dict(colorscale='Rainbow',
-                                                    size=3), name=df.info)
+                             z=df[z][::unsur]-origin_df[z][::unsur],name=df.info)
             xyz_origin = go.Scatter3d(x=np.zeros(1), y=np.zeros(1),
-                             z=np.zeros(1), mode='markers', marker=dict(colorscale='Rainbow',
-                                                    size=5), name=origin_df.info)
-        if color == 'auto':
-            xyz['marker']['color'] = couleur[i]
-        elif color == 'rainbow':
-            xyz['marker']['color'] = df[x]
-            #xyz['marker']['colorscale']='Rainbow'
-        else:
-            xyz['marker']['color'] = color
-        if style_tracer in s:
-            xyz['mode']="markers"
-            xyz['marker']['symbol'] = symbol[s.index(style_tracer)]
-        elif style_tracer in ['-o','o-']:
-            xyz['mode']="lines+markers"
-        else:
-            xyz['mode']="lines"
+                             z=np.zeros(1), mode='markers', marker=dict(size=5), name=origin_df.info)
+        mode_symbol_dask = marker_to_plotly_marker(style_tracer)
+        xyz['mode'] = mode_symbol_dask['mode']
+        if 'markers' in mode_symbol_dask['mode']:
+                #print("**************************jai un marker")
+                xyz['marker']['symbol'] = mode_symbol_dask['symbol']
+                xyz['marker']['size'] = 2
+                if color == 'auto':
+                    xyz['marker']['color'] = couleur[i]
+                elif color == 'rainbow':
+                    xyz['marker']['color'] = df[x]
+                else:
+                    xyz['marker']['color'] = color
+        if 'lines' in mode_symbol_dask['mode']:
+            xyz['line']['dash'] = mode_symbol_dask['dash']
         trace.append(xyz)
         if origin:
             trace.append(xyz_origin) 
+    titx = xlabel if xlabel != '' else x
+    tity = xlabel if ylabel != '' else y
+    titz = xlabel if zlabel != '' else z
     layout = go.Layout(title=titre,margin=dict(l=0,r=0,b=0,t=0),showlegend=True,
-                       scene = dict(aspectmode='data',xaxis = dict(title=x), 
-                                    yaxis = dict(title=y), zaxis=dict(title=z)))
+                       scene = dict(aspectmode='data',xaxis = dict(title=titx), 
+                                    yaxis = dict(title=tity), zaxis=dict(title=titz)))
     fig = go.Figure(data=trace, layout=layout)
 #    (_,_,_,text)=traceback.extract_stack()[-2]
 #    df_name = text[:text.index('.scatter3D')].strip()
@@ -645,17 +676,19 @@ def display_U(self,grandeur,cs=1,percent=0.95):
     return txt
 
 @ set_spy
-def draw_vectors(self,point=('&','&'),vector=('vx','vy'),unsur=1,scalvect=1,titre="sans titre",quadril_x=0,quadril_y=0):
+def draw_vectors(self,point=('&','&'),vector=('vx','vy'),style_tracer='o',unsur=1,scalvect=1,titre="sans titre",quadril_x=0,quadril_y=0,**d):
     if (point == ('&','&')) and len(vector)==3:
         point = ('&','&','&')
     if len(point) == len(vector) == 2:
         x,y = point
         ux,uy = vector
-        self.vector(x=x,y=y,ux=ux,uy=uy,unsur=unsur,scalvect=scalvect,titre=titre,quadril_x=quadril_x,quadril_y=quadril_y)
+        xlabel,ylabel = d.get('xlabel',''),d.get('ylabel','')
+        self.vector(x=x,y=y,ux=ux,uy=uy,unsur=unsur,scalvect=scalvect,titre=titre,quadril_x=quadril_x,quadril_y=quadril_y,xlabel=xlabel,ylabel=ylabel,style_tracer=style_tracer)
     elif len(point) == len(vector) == 3:
         x,y,z = point
         ux,uy,uz = vector
-        self.vector3D(x=x,y=y,z=z,ux=ux,uy=uy,uz=uz,unsur=unsur,scalvect=scalvect,titre=titre,quadril_x=quadril_x,quadril_y=quadril_y)
+        xlabel,ylabel,zlabel = d.get('xlabel',''),d.get('ylabel',''),d.get('zlabel','')
+        self.vector3D(x=x,y=y,z=z,ux=ux,uy=uy,uz=uz,unsur=unsur,scalvect=scalvect,titre=titre,quadril_x=quadril_x,quadril_y=quadril_y,xlabel=xlabel,ylabel=ylabel,zlabel=zlabel,style_tracer=style_tracer)
     else:
         print(f'votre point={point} et vector={vector} ne conviennent pas')
   
@@ -771,7 +804,7 @@ def vector_by_norm_and_direction3D(self,vector_norm,direction='centripetal',x='&
     return result
 
 
-def vector(self,ux,uy,x='&',y='&',unsur=1,scalvect=1,titre="sans titre",quadril_x=0,quadril_y=0,**d):
+def vector(self,ux,uy,x='&',y='&',unsur=1,style_tracer='o',scalvect=1,titre="sans titre",quadril_x=0,quadril_y=0,xlabel='',ylabel='',**d):
     """
         Méthode/Fonction appliquée à une dataframe -> retourne la trajectoire avec des vecteurs.
         Conditions d'utilisation :
@@ -812,8 +845,17 @@ def vector(self,ux,uy,x='&',y='&',unsur=1,scalvect=1,titre="sans titre",quadril_
                        name=f'vecteur ({ux},{uy})',
                        angle=np.pi/12,
                        line=dict(width=1))
-    points = go.Scatter(x=self[xx],y=self[yy],mode='markers',marker=dict(size=4,color='grey'),name=f"Point ({xx},{yy})")
-    layout= go.Layout(title= titre,xaxis= dict(constrain='domain',title= xx,nticks=quadril_x),yaxis=dict(scaleanchor='x',title= yy,nticks=quadril_y))
+    points = go.Scatter(x=self[xx],y=self[yy],name=f"Point ({xx},{yy})")
+    mode_symbol_dask = marker_to_plotly_marker(style_tracer)
+    points['mode'] = mode_symbol_dask['mode']
+    if 'markers' in points['mode']:
+        points['marker']['symbol'] = mode_symbol_dask['symbol']
+    if 'lines' in points['mode']:
+        points['line']['shape']='spline'
+        points['line']['dash'] = mode_symbol_dask['dash']
+    xlab = xx if xlabel =='' else xlabel
+    ylab = yy if ylabel =='' else ylabel
+    layout= go.Layout(title= titre,xaxis= dict(constrain='domain',title= xlab,nticks=quadril_x),yaxis=dict(scaleanchor='x',title= ylab,nticks=quadril_y))
     quiver_fig.add_trace(points)
     quiver_fig['layout'].update(layout)
 #    (_,_,_,text)=traceback.extract_stack()[-2]
@@ -822,7 +864,7 @@ def vector(self,ux,uy,x='&',y='&',unsur=1,scalvect=1,titre="sans titre",quadril_
     return iplot(quiver_fig, filename='vecteur')
 
 
-def vector3D(self,ux,uy,uz,x='&',y='&',z='&',unsur=1,scalvect=1,titre="sans titre",quadril_x=0,quadril_y=0):
+def vector3D(self,ux,uy,uz,x='&',y='&',z='&',unsur=1,scalvect=1,titre="sans titre",quadril_x=0,quadril_y=0,quadril_z=0,xlabel='',ylabel='',zlabel='',style_tracer='o'):
     """
         Méthode/Fonction appliquée à une dataframe -> retourne la trajectoire avec des vecteurs.
         
@@ -860,8 +902,16 @@ def vector3D(self,ux,uy,uz,x='&',y='&',z='&',unsur=1,scalvect=1,titre="sans titr
         print(f"'X ou x' ou 'Y ou y' ou 'Z ou z' ne sont pas des colonnes de votre dataFrame, il faut spécifier un point d'application à vos vecteurs en utilisant x='**' et y='**' ou ** sont parmis\n{self.columns}")
         return None
     scal=scalvect*np.abs((self[xx].max()+self[yy].max()+self[zz].max())/(self[ux].max()+self[uy].max()+self[uz].max()))
-    xyz=go.Scatter3d(x=self[xx], y=self[yy], z=self[zz], mode='markers', marker=dict(colorscale='Rainbow',
-                                                    size=3), name=self.info)
+    xyz=go.Scatter3d(x=self[xx], y=self[yy], z=self[zz], name=self.info)
+    mode_symbol_dask = marker_to_plotly_marker(style_tracer)
+    xyz['mode'] = mode_symbol_dask['mode']
+    if 'markers' in xyz['mode']:
+        xyz['marker']['symbol'] = mode_symbol_dask['symbol']
+    if 'lines' in xyz['mode']:
+        #xyz['line']['shape']='spline'
+        xyz['line']['dash'] = mode_symbol_dask['dash']
+    xyz['marker']['colorscale']='Rainbow'
+    xyz['marker']['size']=3
     trace = []
     trace.append(xyz)
     for i,coordonnees in enumerate(zip(self[xx][::unsur],self[yy][::unsur],self[zz][::unsur],self[ux][::unsur],self[uy][::unsur],self[uz][::unsur])):
@@ -870,7 +920,13 @@ def vector3D(self,ux,uy,uz,x='&',y='&',z='&',unsur=1,scalvect=1,titre="sans titr
         vec_z=[coordonnees[2],coordonnees[2]+scal*coordonnees[5]]
         vector=go.Scatter3d(x=vec_x,y=vec_y,z=vec_z,marker = dict( size = 1),line = dict(width = 2),name='')
         trace.append(vector)
-    layout = go.Layout(title=titre,margin=dict(l=0,r=0,b=0,t=0),scene = {'aspectmode':'data'},showlegend=False)
+    xlab = xx if xlabel =='' else xlabel
+    ylab = yy if ylabel =='' else ylabel
+    zlab = zz if ylabel =='' else ylabel
+    layout = go.Layout(title=titre,margin=dict(l=0,r=0,b=0,t=0),
+                       scene = dict(aspectmode='data',xaxis= dict(title= xlab,nticks=quadril_x),
+                        yaxis=dict(title= ylab,nticks=quadril_y),
+                        zaxis=dict(title= zlab,nticks=quadril_z)),showlegend=False)
     fig = go.Figure(data=trace, layout=layout)
 #    (_,_,_,text)=traceback.extract_stack()[-2]
 #    def_name = text[:text.find('.vector3D')].strip()
@@ -914,7 +970,7 @@ def compute_ntc_model(self,temp='T',resistor='R',**d):
     #print(f"résultat .. ln(R)={resultat[0]}*(1/T)+{resultat[1]}")
     beta = resultat[0]
     R0 = np.exp(resultat[1]+beta/T0)
-    print(f'characteristics of the resistor NTC ... \nBeta={resultat[0]:.1f}\tR0={R0:.1f} Ohm  @{T0-273.15} °C')
+    print(f'characteristics of the resistor NTC ... \nBeta={resultat[0]:.1f}\tR25={R0:.1f} Ohm  @{T0-273.15} °C')
     self['__R_mod']=R0*np.exp(beta*(1/(273.15+self[temp])-1/T0))
     print("\ngraphic of regression")
     self.scatter2D(x=temp,y=[resistor,'__R_mod'],**d)
@@ -1218,7 +1274,7 @@ def f_crypt(y,key,option="crypt"):
         clair = "".join([crypte[(-key+i)%len(crypte)] for i,_ in enumerate(crypte)])
         return "".join([clair[crypte.find(i)] for i in y])
        
-def f_input(txt='',output='float',limit=None,choice=None,sep=','):
+def f_input(txt='',output='float',limit=None,choice=None,sep=',',**d):
     #sep_list = list(r"-,;:_/\")
     sep_list = "/\\,;:-"
     if sep not in sep_list:
@@ -1403,7 +1459,7 @@ def Nasa_horizons_query(id='3',id_type='majorbody', origin='@sun',epochs=dict(st
     print("connect to NASA JPL Horizons ...\r",end='\r')
     obj = Horizons(id=id,id_type=id_type,location=origin,epochs=epochs).vectors().to_pandas()
     astre = obj['targetname'][0]
-    if d.get('display_log',True) == True:
+    if d.get('display_log',True):
         print(f"query of {astre} ..... start={epochs['start']}..end={epochs['stop']}.... finish")
     if d.get('keep_r',False):
         obj.rename({'range':'r'}, axis=1, inplace=True)
@@ -1432,10 +1488,10 @@ def Nasa_position_query(id='3',id_type='majorbody', origin='@sun',date=None):
     obj = Nasa_horizons_query(id=id,id_type=id_type,origin=origin,epochs=dict(start=date,stop=day_after,step='1d'),display_log=False)
     return obj['x'].iloc[0],obj['y'].iloc[0],obj['z'].iloc[0]
 
-def display_progress(x, tot):
+def display_progress(x, tot,ini_txt=''):
     p=int(100*x/tot)
     deb,fin='▓'*p,'░'*(100-p)
-    print('|'+deb+fin+'|'+str(p)+"%",end='\r') 
+    print(ini_txt+' |'+deb+fin+'|'+str(p)+"%",end='\r') 
 
 def anim_bar(xmax,step,dt):
     for i in range(0,xmax,step):
@@ -1567,6 +1623,7 @@ pd.DataFrame.vector3D = vector3D
 pd.DataFrame.regression = regression
 pd.DataFrame.scatter3D = scatter3D
 pd.DataFrame.scatter2D = scatter2D
+pd.DataFrame.scatter1D = scatter1D
 pd.DataFrame.display_U = display_U
 pd.DataFrame.derive = derive
 pd.DataFrame.norme = norme
