@@ -225,6 +225,9 @@ class TestFunctions():
         return final_result
 
     def check_graph(self,txt_c,level=0,suspense=True,**d):
+        """
+        nunez = alt+164
+        """
         TestFunctions.__SPY = TestFunctions.__get_SPY()
         k = d.get('ñ',0)
         if k == TestFunctions.__SPY_KEY:
@@ -271,7 +274,56 @@ class TestFunctions():
                 final_result = False
         return final_result
     
+    def check_var_fnct_other_var(self,glob_var,var1,fnct,*var2s,converters={},**d):
+        """
+
+        Parameters
+        ----------
+        glob_var : globals()
+            DESCRIPTION.
+        var1 : str
+            variable a tester.
+        fnct : fonction tq var1 = f(var2s)
+            DESCRIPTION.
+        *var2s : tuple de str
+            DESCRIPTION.
+
+        Returns
+        -------
+        bool
+            True or False.
+
+        """
+        assert isinstance(var1,str),f"{var1} doit être de type str"
+        for v in var2s:
+            assert isinstance(v,str),f"{v} doit être de type str"
+        if var1 in glob_var:
+            value = glob_var[var1]
+            value = converters.get(var1,lambda x:x)(value)
+            if converters != None:
+                pass
+            value_other = []
+            for v in var2s:
+                value_other.append(converters.get(v,lambda x:x)(glob_var[v]))
+            if np.all(value == fnct(*tuple(value_other))):
+                print(f"{var1} correct défine")
+                return True
+            else:
+                print(f"{var1} isnt correct défine, please retry definition of {var1}")
+                return False
+        else:
+            print(f"variable {var1} n'est pas définie ... recommencez")
+            return False
+            
+            
+    
     def check_var_value(self,glob_var,variable,value,func = None,**d):
+        """ input:
+            *glob_var = globals()
+            *variables: str, name of variable
+            *value: expected value
+            *func: callable (typiccaly lambda), if use, expected value = func(value)
+        """
         assert isinstance(variable,str),"variable must be str"
         if func != None:
             assert callable(func),"func is not a callable ..."
